@@ -29,7 +29,7 @@ error_cb(MafwRenderer* renderer, gpointer user_data, const GError* error);
 MafwSource *app_source = NULL;
 
 static void renderer_state_changed_cb(MafwRenderer *renderer,gint state,gpointer user_data){
- 
+  g_print("renderer_state_changed_cb\n");
   S2s *self = (S2s*)user_data;
   if(state == Stopped){
     
@@ -39,14 +39,14 @@ static void renderer_state_changed_cb(MafwRenderer *renderer,gint state,gpointer
   {
     self->enable =TRUE;
    /*add soource funct */
-    g_timeout_add(150,_next_track,self);
+    g_timeout_add(100,_next_track,self);
   }
   
 }
 
 static void play_status(MafwRenderer *self,MafwPlaylist *playlist,guint index,MafwPlayState state,
 const gchar *object_id,gpointer user_data,const GError *error){
-  
+  g_print("play_status\n");
    S2s *s2s = (S2s*)user_data;
    if(state == Playing)
    {  
@@ -61,7 +61,7 @@ const gchar *object_id,gpointer user_data,const GError *error){
 }
 
 static gboolean _next_track(gpointer user_data){
-  
+  g_print("_next_track\n");
 S2s *self = (S2s*)user_data;
 int x,y,z;
 int rs;
@@ -119,6 +119,7 @@ source_added_cb (MafwRegistry *registry,
 		 GObject *source,
 		 gpointer user_data)
 {
+  g_print("source added\n");
 	if (MAFW_IS_SOURCE(source)) {
 		const gchar *name =
 			mafw_extension_get_name(MAFW_EXTENSION(source));
@@ -133,7 +134,7 @@ renderer_added_cb (MafwRegistry *registry,
 		   GObject *renderer,
 		   gpointer user_data)
 {
-  
+  g_print("renderer added \n");
 	S2s *self = (S2s*)user_data;
 	if (MAFW_IS_RENDERER(renderer)) {
 		//g_print("[INFO] Renderer %s available.\n",mafw_extension_get_name(MAFW_EXTENSION(renderer)));
@@ -154,6 +155,7 @@ renderer_added_cb (MafwRegistry *registry,
 
 gboolean app_init(S2s *self)
 {
+  g_print("app init \n");
 GError *error = NULL;
 GError *err = NULL;
 GList *extension_list = NULL;
@@ -176,24 +178,6 @@ if (error != NULL)
 	error = NULL;
 	return FALSE;
 }
-
-
-/*
-MafwPlaylistManager *manager = mafw_playlist_manager_get ();
-list = mafw_playlist_manager_get_playlists (manager, err);
-
-int i;
-for (i = 0; i < list->len; i++) {
-		playlist = (MafwPlaylist *) g_ptr_array_index (list, i);
-		gchar *name = mafw_playlist_get_name (playlist);
-		g_print("\n %s", name);
-		if (strcmp ("FmpAudioPlaylist",name ) == 0) {
-			mafw_playlist_shuffle(playlist,err);
-		}
-}
-*/
-
-
 /* Connect to extension discovery signals. These signals will be
     emitted when new extensions are started or removed */
 g_signal_connect (registry,
@@ -210,7 +194,7 @@ extension_list = mafw_registry_get_renderers(registry);
 while (extension_list)
 {
 	renderer_added_cb (registry,
-			    G_OBJECT(extension_list->data), NULL);
+			    G_OBJECT(extension_list->data), self);
 	extension_list = g_list_next(extension_list);
 }
 
@@ -222,7 +206,7 @@ main (int argc, gchar *argv[])
 {
 	GMainLoop * main_loop = NULL;
         g_type_init ();
-	g_print("Shake2Control v0.1\n");
+	g_print("Shake2Control v0.3\n");
 	g_print("Sampo Savola 2009\n\n\n");
 	g_print("Listening MAFW...");
 	S2s *self;
